dmqclib.train package
=====================

.. automodule:: dmqclib.train
   :members:
   :show-inheritance:
   :undoc-members:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   dmqclib.train.models
   dmqclib.train.step1_read_input
   dmqclib.train.step2_validate_model
   dmqclib.train.step3_optimise_model
   dmqclib.train.step4_build_model
